summaryrefslogtreecommitdiff
path: root/storage/connect/plgdbsem.h
diff options
context:
space:
mode:
Diffstat (limited to 'storage/connect/plgdbsem.h')
-rw-r--r--storage/connect/plgdbsem.h9
1 files changed, 6 insertions, 3 deletions
diff --git a/storage/connect/plgdbsem.h b/storage/connect/plgdbsem.h
index bbbbc1486b6..e61a49ba9f9 100644
--- a/storage/connect/plgdbsem.h
+++ b/storage/connect/plgdbsem.h
@@ -74,9 +74,10 @@ enum TABTYPE {TAB_UNDEF = 0, /* Table of undefined type */
TAB_PLG = 20, /* PLG NIY */
TAB_PIVOT = 21, /* PIVOT table */
TAB_VIR = 22, /* Virtual tables */
- TAB_JCT = 23, /* Junction tables NIY */
- TAB_DMY = 24, /* DMY Dummy tables NIY */
- TAB_NIY = 25}; /* Table not implemented yet */
+ TAB_JSON = 23, /* JSON tables */
+ TAB_JCT = 24, /* Junction tables NIY */
+ TAB_DMY = 25, /* DMY Dummy tables NIY */
+ TAB_NIY = 26}; /* Table not implemented yet */
enum AMT {TYPE_AM_ERROR = 0, /* Type not defined */
TYPE_AM_ROWID = 1, /* ROWID type (special column) */
@@ -121,6 +122,8 @@ enum AMT {TYPE_AM_ERROR = 0, /* Type not defined */
TYPE_AM_BLK = 131, /* BLK access method type no */
TYPE_AM_ZIP = 132, /* ZIP access method type no */
TYPE_AM_ZLIB = 133, /* ZLIB access method type no */
+ TYPE_AM_JSON = 134, /* JSON access method type no */
+ TYPE_AM_JSN = 135, /* JSN access method type no */
TYPE_AM_MAC = 137, /* MAC table access method type */
TYPE_AM_WMI = 139, /* WMI table access method type */
TYPE_AM_XCL = 140, /* SYS column access method type */